@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = 0.04;
+$VERSION = 0.05;
 
 use Class::Factory::Util;
 use URI;
@@ -25,17 +25,25 @@ sub register_subclass
     }
 }
 
+sub Priority { 100 }
+
 BEGIN
 {
+    my @classes;
+
     for my $class ( map { __PACKAGE__ . '::' . $_ } __PACKAGE__->subclasses )
     {
         eval "use $class";
         die $@ if $@;
 
-        __PACKAGE__->register_subclass( $class );
+        push @classes, { class => $class, priority => $class->Priority };
     }
+
+    __PACKAGE__->register_subclass( $_->{class} )
+        for sort { $a->{priority} <=> $b->{priority} } @classes;
 }
 
+
 use constant NEW_SPEC => { country     => { type => SCALAR },
                            address     => { type => UNDEF | SCALAR, optional => 1 },
                            city        => { type => UNDEF | SCALAR, optional => 1 },
@@ -225,6 +233,12 @@ loaded.
 This class method should return an array of country names which the
 subclass can handle.
 
+=head2 Priority()
+
+Defaults to 100.  Set this to a higher value if your subclass provides
+map links for the same country as another subclass.  The priority goes
+from 1 (highest) to 100 (lowest).
+
 =head2 new()
 
 This method will receive the same parameters as are given to
@@ -252,7 +266,7 @@ URIs generated by these modules.
 
 =head1 SEE ALSO
 
-WebService::StreetMapLink::MapQuest, WebService::StreetMapLink::Multimap, WebService::StreetMapLink::Streetdirectory
+WebService::StreetMapLink::Google, WebService::StreetMapLink::MapQuest, WebService::StreetMapLink::Multimap, WebService::StreetMapLink::Streetdirectory, WebService::StreetMapLink::Catcha
 
 =head1 AUTHOR
 
@@ -267,7 +281,7 @@ be notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2004 David Rolsky, All Rights Reserved.
+Copyright 2004-2005 David Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
